unit CredentialListU;

interface
uses
 System.Generics.Collections;

Type
  ///  <summary>
  ///  Base data for Credential
  ///  </summary>
  TCredential = record
    Username, Password, Domain: string;
    constructor Create(const aUsername, aPassword, aDomain: string);
    function AreEqual(const aUsername, aPassword, aDomain: string): Boolean;
  end;

  ///  <summary>
  ///  List of Credentials
  ///  </summary>
  TCredentialList = class(TList<TCredential>)
  public
  ///  <summary>
  ///  Dummy validator, useing a simple string compare.
  ///  </summary>
    function IsValidCredential(const aUsername, aPassword, aDomain: string): Boolean;
  end;

implementation

uses
  System.SysUtils;

{ TCredential }

function TCredential.AreEqual(const aUsername, aPassword, aDomain: string): Boolean;
begin
  Result := SameText(Username, aUsername) and SameText(Password, aPassword) and SameText(Domain, aDomain);
end;

constructor TCredential.Create(const aUsername, aPassword, aDomain: string);
begin
  Username := aUsername;
  Password := aPassword;
  Domain := aDomain;
end;

{ TCredentialList }

function TCredentialList.IsValidCredential(const aUsername, aPassword, aDomain: string): Boolean;
var
  Credential: TCredential;
begin
  for Credential in Self do
    if Credential.AreEqual(aUsername, aPassword, aDomain) then
      exit(true);

  exit(False);
end;

end.
